@@ -9,8 +9,9 @@ logger.setLevel(log_level)
 # digi metadata and configurations
 g = group = os.environ.get("GROUP", "digi.dev")
 v = version = os.environ.get("VERSION", "v1")
+k = kind = os.environ.get("KIND", "test")
 r = resource = os.environ.get("PLURAL", "tests")
-n = name = os.environ.get("NAME", "test")
+n = name = os.environ.get("NAME", "t1")
 ns = namespace = os.environ.get("NAMESPACE", "default")
 duri = auri = (g, v, r, n, ns)
 
@@ -28,12 +29,16 @@ from digi import (
     mount,
     filter,
     view,
+    data,
+    control,
 )
+_, _ = data, control
 from digi.main import run
-from digi.data import pool
 from digi.reconcile import rc
+model, pool, router = None, None, None
 
 __all__ = [
     "on", "util", "view", "filter",
-    "run", "logger", "mount", "pool", "rc"
+    "run", "logger", "mount", "rc",
+    "model", "pool", "router",
 ]
