@@ -84,6 +84,36 @@ def mount(*args, **kwargs):
     return decorator
 
 
+def ingress(*args, **kwargs):
+    if len(args) >= 1 and callable(args[0]):
+        _attr(path="ingress", *args, **kwargs)
+        return args[0]
+
+    def decorator(fn):
+        if len(args) >= 1:
+            _attr(fn, path="ingress." + args[0], *args[1:], **kwargs)
+        elif "path" in kwargs:
+            _attr(fn, path="ingress." + kwargs.pop("path"), *args, **kwargs)
+        return fn
+
+    return decorator
+
+
+def egress(*args, **kwargs):
+    if len(args) >= 1 and callable(args[0]):
+        _attr(path="egress", *args, **kwargs)
+        return args[0]
+
+    def decorator(fn):
+        if len(args) >= 1:
+            _attr(fn, path="egress." + args[0], *args[1:], **kwargs)
+        elif "path" in kwargs:
+            _attr(fn, path="egress." + kwargs.pop("path"), *args, **kwargs)
+        return fn
+
+    return decorator
+
+
 # XXX test path
 def attr(*args, **kwargs):
     if len(args) >= 1 and callable(args[0]):
@@ -96,8 +126,10 @@ def attr(*args, **kwargs):
 
     return decorator
 
+
 model = attr
 
+
 def _attr(fn, path=".", prio=0):
     # preprocess the path str -> tuple of str
     _path = list()
@@ -232,3 +264,15 @@ def _attr(fn, path=".", prio=0):
            priority=prio,
            condition=filter_.has_diff,
            path=_path)
+
+def new_mount(diff, gvr=None) -> bool:
+    """Detect whether the diffs contain newly mounted digi."""
+    for _diff in diff:
+        op, path, _, _ = _diff
+        if op != "add" or (len(path) > 0 and path[-1] != "generation"):
+            continue
+        if gvr is None and path[:2] == ("spec", "mount"):
+            return True
+        elif path[:3] == ("spec", "mount", gvr):
+            return True
+    return False
